@@ -208,6 +208,10 @@ struct isl_basic_map *isl_basic_map_align_divs(
 		struct isl_basic_map *dst, struct isl_basic_map *src);
 struct isl_basic_set *isl_basic_set_align_divs(
 		struct isl_basic_set *dst, struct isl_basic_set *src);
+__isl_give isl_set *isl_set_align_divs_to_basic_set_list(
+	__isl_take isl_set *set, __isl_keep isl_basic_set_list *list);
+__isl_give isl_basic_set_list *isl_basic_set_list_align_divs_to_basic_set(
+	__isl_take isl_basic_set_list *list, __isl_keep isl_basic_set *bset);
 __isl_give isl_basic_map *isl_basic_map_sort_divs(
 	__isl_take isl_basic_map *bmap);
 __isl_give isl_map *isl_map_sort_divs(__isl_take isl_map *map);
@@ -230,6 +234,8 @@ struct isl_basic_map *isl_basic_map_implicit_equalities(
 struct isl_basic_set *isl_basic_map_underlying_set(struct isl_basic_map *bmap);
 __isl_give isl_basic_set *isl_basic_set_underlying_set(
 		__isl_take isl_basic_set *bset);
+__isl_give isl_basic_set_list *isl_basic_set_list_underlying_set(
+	__isl_take isl_basic_set_list *list);
 struct isl_set *isl_map_underlying_set(struct isl_map *map);
 struct isl_basic_map *isl_basic_map_overlying_set(struct isl_basic_set *bset,
 	struct isl_basic_map *like);
@@ -250,8 +256,12 @@ struct isl_map *isl_map_drop_inputs(
 struct isl_map *isl_map_drop(struct isl_map *map,
 	enum isl_dim_type type, unsigned first, unsigned n);
 
+__isl_give isl_basic_map *isl_basic_map_remove_duplicate_constraints(
+	__isl_take isl_basic_map *bmap, int *progress, int detect_divs);
+
 struct isl_map *isl_map_remove_empty_parts(struct isl_map *map);
 struct isl_set *isl_set_remove_empty_parts(struct isl_set *set);
+__isl_give isl_map *isl_map_remove_obvious_duplicates(__isl_take isl_map *map);
 
 struct isl_set *isl_set_normalize(struct isl_set *set);
 
@@ -274,6 +284,8 @@ int isl_basic_set_constraint_is_redundant(struct isl_basic_set **bset,
 int isl_basic_map_add_div_constraint(__isl_keep isl_basic_map *bmap,
 	unsigned div, int sign);
 int isl_basic_map_add_div_constraints(struct isl_basic_map *bmap, unsigned div);
+__isl_give isl_basic_map *isl_basic_map_add_known_div_constraints(
+	__isl_take isl_basic_map *bmap);
 struct isl_basic_map *isl_basic_map_drop_redundant_divs(
 	struct isl_basic_map *bmap);
 struct isl_basic_set *isl_basic_set_drop_redundant_divs(
@@ -381,6 +393,12 @@ __isl_give isl_set *isl_set_fix(__isl_take isl_set *set,
 int isl_map_plain_is_fixed(__isl_keep isl_map *map,
 	enum isl_dim_type type, unsigned pos, isl_int *val);
 
+int isl_basic_map_output_defining_equality(__isl_keep isl_basic_map *bmap,
+	int pos);
+
+__isl_give isl_basic_set_list *isl_set_get_basic_set_list(
+	__isl_keep isl_set *set);
+
 __isl_give isl_map *isl_map_fixed_power(__isl_take isl_map *map, isl_int exp);
 
 int isl_basic_set_count_upto(__isl_keep isl_basic_set *bset,
